# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/pingme',
                'doc_host': 'https://$GIT_USER_NAME.github.io',
                'git_url': 'https://github.com/$GIT_USER_NAME/pingme',
                'lib_path': 'pingme'},
  'syms': { 'pingme.api': { 'pingme.api.Settings': ('pingme_api.html#settings', 'pingme/api.py'),
                            'pingme.api.read_main': ('pingme_api.html#read_main', 'pingme/api.py'),
                            'pingme.api.send_webhook': ('pingme_api.html#send_webhook', 'pingme/api.py'),
                            'pingme.api.send_webhook_test': ('pingme_api.html#send_webhook_test', 'pingme/api.py'),
                            'pingme.api.webservice': ('pingme_api.html#webservice', 'pingme/api.py')},
            'pingme.core': { 'pingme.core.cli': ('core.html#cli', 'pingme/core.py'),
                             'pingme.core.get_config': ('core.html#get_config', 'pingme/core.py'),
                             'pingme.core.get_samplesheet': ('core.html#get_samplesheet', 'pingme/core.py'),
                             'pingme.core.hello_world': ('core.html#hello_world', 'pingme/core.py'),
                             'pingme.core.set_env_variables': ('core.html#set_env_variables', 'pingme/core.py'),
                             'pingme.core.show_project_env_vars': ('core.html#show_project_env_vars', 'pingme/core.py')},
            'pingme.hello_world': { 'pingme.hello_world.cli': ('hello_world.html#cli', 'pingme/hello_world.py'),
                                    'pingme.hello_world.hello_two_world': ('hello_world.html#hello_two_world', 'pingme/hello_world.py')},
            'pingme.pingme_class': { 'pingme.pingme_class.Card': ('pingme_class.html#card', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.PingMe': ('pingme_class.html#pingme', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.PingMe.__init__': ('pingme_class.html#pingme.__init__', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.PingMe.__repr__': ('pingme_class.html#pingme.__repr__', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.PingMe.__str__': ('pingme_class.html#pingme.__str__', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.PingMe.send_email': ( 'pingme_class.html#pingme.send_email',
                                                                                'pingme/pingme_class.py'),
                                     'pingme.pingme_class.PingMe.send_logfile': ( 'pingme_class.html#pingme.send_logfile',
                                                                                  'pingme/pingme_class.py'),
                                     'pingme.pingme_class.PingMe.send_webhook': ( 'pingme_class.html#pingme.send_webhook',
                                                                                  'pingme/pingme_class.py'),
                                     'pingme.pingme_class.cli': ('pingme_class.html#cli', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.resolved_payload': ( 'pingme_class.html#resolved_payload',
                                                                               'pingme/pingme_class.py'),
                                     'pingme.pingme_class.send_to_email': ('pingme_class.html#send_to_email', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.send_to_logfile': ('pingme_class.html#send_to_logfile', 'pingme/pingme_class.py'),
                                     'pingme.pingme_class.send_to_webhook': ( 'pingme_class.html#send_to_webhook',
                                                                              'pingme/pingme_class.py')}}}
